###### Indirect impacts of a non-native ungulate browser on soil ecosystem function is variable across 
####   soil horizons in the boreal forests of Newfoundland, Canada
#### ------------------------------------------------------------------------------------------------
####
####  Makayla Swain, Shawn J. Leroux, Robert Buchkowski
####
####
####  Code to replicate analyses and figures presented in paper
####  -----------------------------------------------------------
####
####  CONTENTS:
####  ---------
####  1. Set-up:
####      a) Packages needed
####      b) Data needed
####      c) Summarize data by plot
####
####  2. Structural Equation Model (SEM)
####      a) Individual SEM Pathways for the First Soil Horizon 
####      b) Individual SEM Pathways for the Second Soil Horizon 
####      c) SEM examining indirect impacts of moose for the First and Second Soil Horizon
####  
####  3. Sub-Analysis and Figures 
####      a) Run Each Sub Analysis Pathway
####      b) Create Figures for Sub Analysis and SEM
####  
###########################################################################################################################################

library("lme4") # For mixed-modelling
library("MuMIn") # For R2 on GLMM
library("Hmisc") # For correlation
library("nlme")
library("dplyr") #for manipulating data
library("car") #scatterplot
library("plotrix")
library("multcomp") #tukey's HSD
library("multcompView")
library("devtools")
library("vegan")
library("piecewiseSEM") # For SEM procedure. Note we load most up-to-date version of package from Lefcheck website below.
#https://github.com/jslefche/piecewiseSEM
install_github("jslefche/piecewiseSEM@devel", build_vignette = TRUE)
vignette("piecewiseSEM")
library(tidyverse)
library(dtplyr)

################
# b. Data needed
################
# Load in Exclosure and Control data on vegetation, soils, and organism communities for SEM and Sub Analysis
moose.indirect <- read.csv("Moose_Indirect_Impacts_SEM.csv")
## Remove Sites with missing (i.e., NA) or incorrect/implausible parameters.  Seperated by soil horizon  
  ###First soil horizon 
  ###Site Codes: PC-E3, BHW-E2, BHW-E3, BHW-C4, BHC-E4, MT-E3, HB-E3, HB-C3, HB-C4, OH-E1, OH-C1, OH-C3, BC-C1
  moose.indirect.First <- moose.indirect %>%
      filter(!row_number() %in% c(3,18,19,24,44,51,59,63,64,65,69,71,77))   

  ###Second soil horizon
  ###Site Codes: BHW-E2, BHW-C4, OT-E1, OT-E3, OT-C2 BCC-E2, BCC-E3, BHC-E4, BHC-C1, HB-E3, OH-E1, OH-C1, OH-C2, OH-C3, BC-C1, BC-C3
  moose.indirect.Second <-  moose.indirect %>%
      filter(!row_number() %in% c(18,24,25,27,30,34,35,44,45,59,65,69,70,71,77,79))

  ### Convert DIN and Microbial C and N (O horizon) to numeric if reading as character
    moose.indirect.First$microbial.o.c <- as.numeric(as.character(moose.indirect.First$microbial.o.c))
    moose.indirect.First$microbial.o.n <- as.numeric(as.character(moose.indirect.First$microbial.o.n))
    moose.indirect.First$din.o <- as.numeric(as.character(moose.indirect.First$din.o))
    moose.indirect.Second$din.a <- as.numeric(as.character(moose.indirect.Second$din.a))

#save these files
    write.csv(moose.indirect.First, "moose.indirect.First.csv")
    write.csv(moose.indirect.Second, "moose.indirect.Second.csv")

# Load in Data set for sub-analysis.
    temp.water <- read.csv("Temperature_WaterContent.csv")
    View(temp.water)
############################
# c. Summarize data by plot
###########################

#Here we combine sub-plot data to get one value per plot
#First horizon
#Import data frame created above
    moose.indirect.First <- read.csv("moose.indirect.First.csv")
#We take mean of sub-plot value for most variables
moose.first.mean <- moose.indirect.First %>% group_by(Site,E.C, budworm) %>% 
      summarise(across(c(sap.pal, din.o, din.a, shrubs.cover, per.moist.a, per.moist.o, per.c.o, per.n.o, per.c.a, per.n.a, o.len, o.pmat, microbial.o.n, microbial.o.c, microbial.a.n, microbial.a.c),mean),
                .groups = 'drop') %>%
      as.data.frame()
    
#We take sum of adult count because we need an integer value and sum of trees at plot level is most informative
moose.first.adults <- moose.indirect.First %>% group_by(Site,E.C, budworm) %>% 
      summarise(across(c(adult.count),sum),
                .groups = 'drop') %>%
      as.data.frame()

#Add adult sum to table of means above
moose.first.mean$adult.count.total <- moose.first.adults$adult.count

#Second horizon
#Import data frame created above
moose.indirect.Second <- read.csv("moose.indirect.Second.csv")

#We take mean of sub-plot value for most variables
moose.second.mean <- moose.indirect.Second %>% group_by(Site,E.C, budworm) %>% 
      summarise(across(c(sap.pal, din.o, din.a, shrubs.cover, per.moist.a, per.moist.o, per.c.o, per.n.o, per.c.a, per.n.a, o.len, o.pmat, microbial.o.n, microbial.o.c, microbial.a.n, microbial.a.c),mean),
                .groups = 'drop') %>%
      as.data.frame()
    
#We take sum of adult count because we need an integer value and sum of trees at plot level is most informative
moose.second.adults <- moose.indirect.Second %>% group_by(Site,E.C, budworm) %>% 
      summarise(across(c(adult.count),sum),
                .groups = 'drop') %>%
      as.data.frame()
    
#Add adult sum to table of means above
moose.second.mean$adult.count.total <- moose.second.adults$adult.count

#Temperature and water data summarized by plot
#We take mean of sub-plot value for most variables
temp.water.mean <- temp.water %>% group_by(Site,E.C) %>% 
  summarise(across(c(T,M),mean),
            .groups = 'drop') %>%
  as.data.frame()
    

############################################
#### Part 2: Structural Equation Model (SEM)
########################################################
## a. Individual SEM Pathways for the First Soil Horizon
########################################################
#Test each Individual Pathway using Liner Mixed Models. Base models to be input into SEM. Site as a Random Variable.
#Note that sapling model does not converge so we will drop that variable from the models
#We compute and report mean and sd of sapling height in exclosure and control and report that in ms
mean(moose.first.mean$sap.pal[moose.first.mean$E.C=="E"])
sd(moose.first.mean$sap.pal[moose.first.mean$E.C=="E"])
mean(moose.first.mean$sap.pal[moose.first.mean$E.C=="C"])
sd(moose.first.mean$sap.pal[moose.first.mean$E.C=="C"])

#We compute and report mean and sd of adult trees in the three disturbance categories
mean(moose.first.mean$adult.count.total[moose.first.mean$budworm=="Closed"])
sd(moose.first.mean$adult.count.total[moose.first.mean$budworm=="Closed"])
mean(moose.first.mean$adult.count.total[moose.first.mean$budworm=="Partial"])
sd(moose.first.mean$adult.count.total[moose.first.mean$budworm=="Partial"])
mean(moose.first.mean$adult.count.total[moose.first.mean$budworm=="Open"])
sd(moose.first.mean$adult.count.total[moose.first.mean$budworm=="Open"])

#We compute and report mean and sd of adult trees in exclosure and control and report that in ms
mean(moose.first.mean$adult.count.total[moose.first.mean$E.C=="E"])
sd(moose.first.mean$adult.count.total[moose.first.mean$E.C=="E"])
mean(moose.first.mean$adult.count.total[moose.first.mean$E.C=="C"])
sd(moose.first.mean$adult.count.total[moose.first.mean$E.C=="C"])

## Path 1
### Count of Adult Trees
path1.first.mean<-glmer(adult.count.total ~ E.C + budworm + (1|Site), family=poisson, data=moose.first.mean)
###visually check residuals
res.path1.first.mean<-resid(path1.first.mean)
fit.path1.first.mean<-fitted(path1.first.mean)
plot(fit.path1.first.mean,res.path1.first.mean)
lag.plot(res.path1.first.mean,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.path1.first.mean)
qqline(res.path1.first.mean)

summary(path1.first.mean)
r.squaredGLMM(path1.first.mean)

## Path 2
### Percent Shrub coverage 
path2.first.mean<-lmer(shrubs.cover ~ E.C + adult.count.total + per.moist.o + o.pmat + (1|Site),  data=moose.first.mean)
###visually check residuals
res.path2.first.mean<-resid(path2.first.mean)
fit.path2.first.mean<-fitted(path2.first.mean)
plot(fit.path2.first.mean,res.path2.first.mean)
lag.plot(res.path2.first.mean,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.path2.first.mean)
qqline(res.path2.first.mean)

summary(path2.first.mean)
r.squaredGLMM(path2.first.mean)

## Path 3
### Microbial Biomass C:N Ratio (First horizon)
#### Create Microbial C:N ratio 
moose.first.mean$microbial.CN <- moose.first.mean$microbial.o.c/moose.first.mean$microbial.o.n
path3.first.mean<-lmer(microbial.CN ~ shrubs.cover + per.moist.o + o.pmat + (1|Site), data=moose.first.mean)
###visually check residuals
res.path3.first.mean<-resid(path3.first.mean)
fit.path3.first.mean<-fitted(path3.first.mean)
plot(fit.path3.first.mean,res.path3.first.mean)
lag.plot(res.path3.first.mean,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.path3.first.mean)
qqline(res.path3.first.mean)

summary(path3.first.mean)
r.squaredGLMM(path3.first.mean)


## Path 4
### Potential N Mineralization  (First horizon)
path4.first.mean<-lmer(din.o ~ microbial.CN + (1|Site), data=moose.first.mean)
###visually check residuals
res.path4.first.mean<-resid(path4.first.mean)
fit.path4.first.mean<-fitted(path4.first.mean)
plot(fit.path4.first.mean,res.path4.first.mean)
lag.plot(res.path4.first.mean,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.path4.first.mean)
qqline(res.path4.first.mean)

summary(path4.first.mean)
r.squaredGLMM(path4.first.mean)

#########################################################
## b. Individual SEM Pathways for the Second Soil Horizon
#########################################################
#Test each Individual Pathway using Liner Mixed Models. Base models to be input into SEM. Site as a Random Variabl.
#Note that sapling model does not converge so we will drop that variable from the models

## Path 1
### Count of Adult Trees
path1.second<-glmer(adult.count.total ~ E.C + budworm + (1|Site), family=poisson, data=moose.second.mean)
###visually check residuals
res.path1.second<-resid(path1.second)
fit.path1.second<-fitted(path1.second)
plot(fit.path1.second,res.path1.second)
lag.plot(res.path1.second,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.path1.second)
qqline(res.path1.second)
###check output
summary(path1.second)
r.squaredGLMM(path1.second)


## Path 2
### Percent Shrub coverage 
path2.second<-lmer(shrubs.cover ~ E.C + adult.count.total + per.moist.a + o.pmat + (1|Site),  data=moose.second.mean)
###visually check residuals
res.path2.second<-resid(path2.second)
fit.path2.second<-fitted(path2.second)
plot(fit.path2.second,res.path2.second)
lag.plot(res.path2.second,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.path2.second)
qqline(res.path2.second)
###check output
summary(path2.second)
r.squaredGLMM(path2.second)

## Path 3
### Microbial Biomass C:N Ratio (First horizon)
#### Create Microbial C:N ratio 
moose.second.mean$microbial.CN <- moose.second.mean$microbial.a.c/moose.second.mean$microbial.a.n
path3.second<-lmer(microbial.CN ~ shrubs.cover + per.moist.a + o.pmat + (1|Site), data=moose.second.mean)
###visually check residuals
res.path3.second<-resid(path3.second)
fit.path3.second<-fitted(path3.second)
plot(fit.path3.second,res.path3.second)
lag.plot(res.path3.second,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.path3.second)
qqline(res.path3.second)
###check output
summary(path3.second)
r.squaredGLMM(path3.second)

## Path 4
### Potential N Mineralization  (First horizon)
path4.second<-lmer(din.a ~ microbial.CN + (1|Site), data=moose.second.mean)
###visually check residuals
res.path4.second<-resid(path4.second)
fit.path4.second<-fitted(path4.second)
plot(fit.path4.second,res.path4.second)
lag.plot(res.path4.second,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.path4.second)
qqline(res.path4.second)
###check output
summary(path4.second)
r.squaredGLMM(path4.second)

###################################################################################
## c. SEM examining indirect impacts of moose for the First and Second Soil Horizon
###################################################################################
# Run SEM with each tested pathway
##First Horizon
modelo.1<-psem(glmer(adult.count.total ~ E.C + budworm + (1|Site), family=poisson, data=moose.first.mean),
               lmer(shrubs.cover ~ E.C + adult.count.total + per.moist.o + o.pmat + (1|Site), data=moose.first.mean),
               lmer(microbial.CN ~ shrubs.cover + per.moist.o + o.pmat + (1|Site), data=moose.first.mean),
               lmer(din.o ~ microbial.CN + (1|Site), data=moose.first.mean))
summary(modelo.1)
    
    
##Second Horizon
modela.1<-psem(glmer(adult.count.total ~ E.C + budworm + (1|Site), family=poisson, data=moose.second.mean),
               lmer(shrubs.cover ~ E.C + adult.count.total + per.moist.a + o.pmat + (1|Site), data=moose.second.mean),
               lmer(microbial.CN ~ shrubs.cover + per.moist.a + o.pmat + (1|Site), data=moose.second.mean),
               lmer(din.a ~ microbial.CN + (1|Site), data=moose.second.mean))
summary(modela.1)

##Model contains 2 missing relationships.  Add these relationships as correlated errors to increase goodness of fit.
###Adult Tree Count ~ % Second Horizon Moisture, N Min ~ % Second Horizon Moisture
modela.2<-psem(glmer(adult.count.total ~ E.C + budworm + (1|Site), family=poisson, data=moose.second.mean),
                lmer(shrubs.cover ~ E.C + adult.count.total + per.moist.a + o.pmat + (1|Site), data=moose.second.mean),
                lmer(microbial.CN ~ shrubs.cover + per.moist.a + o.pmat + (1|Site), data=moose.second.mean),
                lmer(din.a ~ microbial.CN + (1|Site), data=moose.second.mean),
                adult.count.total %~~% per.moist.a,
                din.a %~~% per.moist.a)
summary(modela.2)


############################################
#### Part 3: Sub-Analysis and Figures
########################################################
## a. Run Each Sub Analysis Pathway
########################################################
#Run a Liner Mixed Model for each Sub Analysis. Site included as a Random Variabl.    
    ## Soil Temperature
      path.st <-lmer(T ~ E.C + (1|Site), data=temp.water.mean)
      #visually check residuals
      res.path.st <-resid(path.st)
      fit.path.st <-fitted(path.st)
      plot(fit.path.st,res.path.st)
      lag.plot(res.path.st,
               diag=FALSE,
               do.line=FALSE)
      qqnorm(res.path.st)
      qqline(res.path.st)
      #check output
      summary(path.st)
      r.squaredGLMM(path.st) 

mean(temp.water.mean$T[temp.water.mean$E.C=="E"])
sd(temp.water.mean$T[temp.water.mean$E.C=="E"])
mean(temp.water.mean$T[temp.water.mean$E.C=="C"])
sd(temp.water.mean$T[temp.water.mean$E.C=="C"])      

#Soil water content model does not converge
    ## Soil Water Content
      path.swc <-lmer(M ~ E.C + (1|Site), data=temp.water.mean)
      #visually check residuals
      res.path.swc <-resid(path.swc)
      fit.path.swc <-fitted(path.swc)
      plot(fit.path.swc,res.path.swc)
      lag.plot(res.path.swc,
               diag=FALSE,
               do.line=FALSE)
      qqnorm(res.path.swc)
      qqline(res.path.swc)
      #check output
      summary(path.swc)
      r.squaredGLMM(path.swc)
      
#Take means of E and C plus sd to report these.
mean(temp.water.mean$M[temp.water.mean$E.C=="E"])
sd(temp.water.mean$M[temp.water.mean$E.C=="E"])
mean(temp.water.mean$M[temp.water.mean$E.C=="C"])
sd(temp.water.mean$M[temp.water.mean$E.C=="C"])
      
########################################################
## b. Create Figures for Sub Analysis and SEM
########################################################
#SEM Figures 
  ##Make Exclosure and Contol variables numerical for plotting
      moose.indirect.plot <- data.frame(moose.first.mean)
      moose.indirect.plot ['E.C'][moose.indirect.plot['E.C'] == 'E' ] <- 1
      moose.indirect.plot ['E.C'][moose.indirect.plot['E.C'] == 'C' ] <- 2
      moose.indirect.plot$E.C <- as.numeric(as.character(moose.indirect.plot$E.C))
  ##Create Data Subset for each Site
    pc <- subset(moose.indirect.plot, Site=="PC")
    bhe <- subset(moose.indirect.plot, Site=="BHE")
    bhw <- subset(moose.indirect.plot, Site=="BHW")
    ot <- subset(moose.indirect.plot, Site=="OT")
    bcc <- subset(moose.indirect.plot, Site=="BCC")
    bhc <- subset(moose.indirect.plot, Site=="BHC")
    mt <- subset(moose.indirect.plot, Site=="MT")
    hb <- subset(moose.indirect.plot, Site=="HB")
    oh <- subset(moose.indirect.plot, Site=="OH")
    bc <- subset(moose.indirect.plot, Site=="BC")
    fm <- subset(moose.indirect.plot, Site=="FM")
 
  ## Figures of Above Ground Pathways
    
    ### Create Figure Layout
      par(mfrow = c(1,3))
    ### Create each Boxplot
      #Adult Tree Count
      boxplot(moose.indirect.plot$adult.count.total~moose.indirect.plot$E.C,
            names= c("Exclosure","Control"),
            ylab= "Adult Tree Count",
            xlab= " ",
            main ="", cex.lab=1.5, cex.axis=1.5)
      mtext(expression(bold("a)")), side = 3, adj = 0, line = 1)
        ## Add Each Sites Data as Points 
          ###Adult Tree Count
            points(pc$adult.count.total~pc$E.C,  pch=21, cex=2)
            points(bhe$adult.count.total~jitter(bhe$E.C, factor = .5), pch=22, , cex=2)
            points(bhw$adult.count.total~jitter(bhw$E.C, factor = .5), pch=23, cex=2)
            points(ot$adult.count.total~jitter(ot$E.C, factor = .75), pch=24, cex=2)
            points(bcc$adult.count.total~jitter(bcc$E.C, factor = .75), pch=25, cex=2)
            points(bhc$adult.count.total~jitter(bhc$E.C, factor = 1), pch=11, cex=2)
            points(mt$adult.count.total~jitter(mt$E.C, factor = 1), pch=17, cex=2)
            points(hb$adult.count.total~jitter(hb$E.C, factor = .25), pch=13, cex=2)
            points(oh$adult.count.total~jitter(oh$E.C, factor = 1.25), pch=19, cex=2)
            points(bc$adult.count.total~jitter(bc$E.C, factor = 1.25), pch=15, cex=2)
            points(fm$adult.count.total~jitter(fm$E.C, factor = .25), pch=14, cex=2)
      #Paletable Sapling Count
      boxplot(moose.indirect.plot$sap.pal~moose.indirect.plot$E.C,
            names= c("Exclosure","Control"),
            ylab= "Mean Height of Palatable Saplings (cm)",
            xlab= " ",
            main ="", cex.lab=1.5, cex.axis=1.5)
      mtext(expression(bold("b)")), side = 3, adj = 0, line = 1)
        ## Add Each Sites Data as Points 
          ###Paletable Sapling Count
            points(pc$sap.pal~pc$E.C,  pch=21, cex=2)
            points(bhe$sap.pal~jitter(bhe$E.C, factor = .5), pch=22, cex=2)
            points(bhw$sap.pal~jitter(bhw$E.C, factor = .5), pch=23, cex=2)
            points(ot$sap.pal~jitter(ot$E.C, factor = .75), pch=24, cex=2)
            points(bcc$sap.pal~jitter(bcc$E.C, factor = .75), pch=25, cex=2)
            points(bhc$sap.pal~jitter(bhc$E.C, factor = 1), pch=11, cex=2)
            points(mt$sap.pal~jitter(mt$E.C, factor = 1), pch=17, cex=2)
            points(hb$sap.pal~jitter(hb$E.C, factor = .25), pch=13, cex=2)
            points(oh$sap.pal~jitter(oh$E.C, factor = 1.25), pch=19, cex=2)
            points(bc$sap.pal~jitter(bc$E.C, factor = 1.25), pch=15, cex=2)
            points(fm$sap.pal~jitter(fm$E.C, factor = .25), pch=14, cex=2)
      #Shrub Percent Cover
      boxplot(moose.indirect.plot$shrubs.cover~moose.indirect.plot$E.C,
            names= c("Exclosure","Control"),
            ylab= "Percent Shrub Cover",
            xlab= " ",
            main ="", cex.lab=1.5, cex.axis=1.5)
    mtext(expression(bold("c)")), side = 3, adj = 0, line = 1)
      ## Add Each Sites Data as Points 
        ###Shrub Percent Cover
            points(pc$shrubs.cover~pc$E.C,  pch=21, cex=2)
            points(bhe$shrubs.cover~jitter(bhe$E.C, factor = .5), pch=22, cex=2)
            points(bhw$shrubs.cover~jitter(bhw$E.C, factor = .5), pch=23, cex=2)
            points(ot$shrubs.cover~jitter(ot$E.C, factor = .75), pch=24, cex=2)
            points(bcc$shrubs.cover~jitter(bcc$E.C, factor = .75), pch=25, cex=2)
            points(bhc$shrubs.cover~jitter(bhc$E.C, factor = 1), pch=11, cex=2)
            points(mt$shrubs.cover~jitter(mt$E.C, factor = 1), pch=17, cex=2)
            points(hb$shrubs.cover~jitter(hb$E.C, factor = .25), pch=13, cex=2)
            points(oh$sap.pal~jitter(oh$E.C, factor = 1.25), pch=19, cex=2)
            points(bc$sap.pal~jitter(bc$E.C, factor = 1.25), pch=15, cex=2)
            points(fm$shrubs.cover~jitter(fm$E.C, factor = .25), pch=14, cex=2)
  
   
#Sub-analysis Figures
  ##Make Exclosure and Contol variables numerical for plotting
    temp.water.mean ['E.C'][temp.water.mean['E.C'] == 'E' ] <- 1
    temp.water.mean ['E.C'][temp.water.mean['E.C'] == 'C' ] <- 2
    temp.water.mean$E.C <- as.numeric(as.character(temp.water.mean$E.C)) 
  ##Create Data Subset for each Site
    ###Temperature
    pc_t <- subset(temp.water.mean, Site=="PC")
    bhe_t <- subset(temp.water.mean, Site=="BHE")
    bhw_t <- subset(temp.water.mean, Site=="BHW")
    ot_t <- subset(temp.water.mean, Site=="OT")
    bcc_t <- subset(temp.water.mean, Site=="BCC")
    bhc_t <- subset(temp.water.mean, Site=="BHC")
    mt_t <- subset(temp.water.mean, Site=="MT")
    hb_t <- subset(temp.water.mean, Site=="HB")
    oh_t <- subset(temp.water.mean, Site=="OH")
    bc_t <- subset(temp.water.mean, Site=="BC")
    fm_t <- subset(temp.water.mean, Site=="FM")
    ###Water Content
    pc_w <- subset(temp.water.mean, Site=="PC")
    bhe_w <- subset(temp.water.mean, Site=="BHE")
    bhw_w <- subset(temp.water.mean, Site=="BHW")
    ot_w <- subset(temp.water.mean, Site=="OT")
    bcc_w <- subset(temp.water.mean, Site=="BCC")
    bhc_w <- subset(temp.water.mean, Site=="BHC")
    mt_w <- subset(temp.water.mean, Site=="MT")
    hb_w <- subset(temp.water.mean, Site=="HB")
    oh_w <- subset(temp.water.mean, Site=="OH")
    bc_w <- subset(temp.water.mean, Site=="BC")
    fm_w <- subset(temp.water.mean, Site=="FM")
  ## Figures of Above Ground Pathways
    ### Create Figure Layout
      par(mfrow = c(1,2))
    ### Create each Boxplot
      ###Temperature
        boxplot(temp.water.mean$T~temp.water.mean$E.C,
              names= c("Exclosure","Control"),
              ylab= "Soil Temperature (Celcius)",
              xlab= " ",
              main ="")
        mtext(expression(bold("a)")), side = 3, adj = 0, line = 1)
      ### Add Each Sites Data as Points 
        points(pc_t$T~jitter(pc_t$E.C, factor=1.5),  pch=21,cex=1.5)
        points(bhe_t$T~jitter(bhe_t$E.C, factor = .5), pch=22,cex=1.5)
        points(bhw_t$T~jitter(bhw_t$E.C, factor = .5), pch=23,cex=1.5)
        points(ot_t$T~jitter(ot_t$E.C, factor = .75), pch=24,cex=1.5)
        points(bcc_t$T~jitter(bcc_t$E.C, factor = .75), pch=25,cex=1.5)
        points(bhc_t$T~jitter(bhc_t$E.C, factor = 1), pch=11,cex=1.5)
        points(mt_t$T~jitter(mt_t$E.C, factor = 1), pch=17,cex=1.5)
        points(hb_t$T~jitter(hb_t$E.C, factor = .25), pch=13,cex=1.5)
        points(oh_t$T~jitter(oh_t$E.C, factor = 1.25), pch=19,cex=1.5)
        points(bc_t$T~jitter(bc_t$E.C, factor = 1.25), pch=15,cex=1.5)
        points(fm_t$T~jitter(fm_t$E.C, factor = .25), pch=14,cex=1.5)
      
      ###Water Content
        boxplot(temp.water.mean$M~temp.water.mean$E.C,
              names= c("Exclosure","Control"),
              ylab= "Soil Water Content (m^3/m^3)",
              xlab= " ",
              main ="")
        mtext(expression(bold("b)")), side = 3, adj = 0, line = 1)
      ### Add Each Sites Data as Points 
        points(pc_w$M~jitter(pc_w$E.C, factor= 1.5),  pch=21,cex=1.5)
        points(bhe_w$M~jitter(bhe_w$E.C, factor = .5), pch=22,cex=1.5)
        points(bhw_w$M~jitter(bhw_w$E.C, factor = .5), pch=23,cex=1.5)
        points(ot_w$M~jitter(ot_w$E.C, factor = .75), pch=24,cex=1.5)
        points(bcc_w$M~jitter(bcc_w$E.C, factor = .75), pch=25,cex=1.5)
        points(bhc_w$M~jitter(bhc_w$E.C, factor = 1), pch=11,cex=1.5)
        points(mt_w$M~jitter(mt_w$E.C, factor = 1), pch=17,cex=1.5)
        points(hb_w$M~jitter(hb_w$E.C, factor = .25), pch=13,cex=1.5)
        points(oh_w$M~jitter(oh_w$E.C, factor = 1.25), pch=19,cex=1.5)
        points(bc_w$M~jitter(bc_w$E.C, factor = 1.25), pch=15,cex=1.5)
        points(fm_w$M~jitter(fm_w$E.C, factor = .25), pch=14,cex=1.5)
        
